/*
 * This is a collection of styles thrown together fast.
 * In other words, don't use these....
 */

body {
    margin: 0;
    padding: 0;
    font-size: 100%;
}

#banner {
    font-size: 120%;
    color: white;
    background-color: blue;
    height: 4em;
    width: 100%;
}

#footer {
    font-size: 80%;
    color: white;
    background-color: blue;
    height: 4em;
    width: 100%;
}

#wrapper {
    margin: 3em;
    padding: 1em;
}
#menu {
    border-bottom : 1px solid #ccc;
    margin : 0;
    padding-bottom : 19px;
    padding-left : 10px;
}

#menu ul, #menu li      {
    display : inline;
    list-style-type : none;
    margin : 0;
    padding : 0;
}

#menu a:link, #menu a:visited   {
    background : #E8EBF0;
    border : 1px solid #ccc;
    color : #666;
    float : left;
    font-size : small;
    font-weight : normal;
    line-height : 14px;
    margin-right : 8px;
    padding : 2px 10px 2px 10px;
    text-decoration : none;
}

#menu a:link.active, #menu a:visited.active     {
    background : #fff;
    border-bottom : 1px solid #fff;
    color : #000;
}

#menu a:hover   {
    color : #f00;
}


 #menu ul a:hover {
    color : #f00 !important;
}

#content {
    background : #fff;
    border : 1px solid #ccc;
    border-top : none;
    clear : both;
    margin : 0px;
    padding : 15px;
}


/* Common Form Styles */

    .stdform legend {
        font-size: 130%;
    }

    .stdform fieldset fieldset legend {
        border: none;
    }


    .stdform div {
        padding-bottom: 10px;       /* Spacing between widget groups */
    }

    .stdform input.readonly {
        border: 1px dashed gray;
    }

    /* Clear after each widget */

    br.widget {
        clear: left;                /* Make sure widgets clear */
    }


    .required label {
        font-weight: bold;
        color: red;
    }

    .stdform fieldset {
        margin-top: 2em;
        /* -moz-border-radius: 4%; */
    }

    .stdform fieldset fieldset {
        margin-top: 0;
    }



    .rcheck input {
        margin-left: 23%;
    }




/* Text-type fields with left labels */

    div.ltext {
        margin-bottom: 1em;
    }

    .ltext label, .ltext input {
        display: block;
        float: left;  /* float both left */
    }

    .ltext label {
        text-align: right;
        width: 20%;
        padding-right: 1em;
    }

    .ltext input {
        width: 45%;
        padding-left: 5px;
        border: 1px solid #555;
    }


    .FutureDate input, .DateTime input, .DateTimeManip input {
        width: 20em;
    }

    .DateTimeDMYHM label  {
        width: auto;
    }
    .DateTimeDMYHM input  {
        display: inline;
        float: none;
        width: 3em;
    }


    /* Override input fields that are integer fields */
    .Integer input, .PosInteger input {
        width: 10%;
    }

/* Radio and Checkboxes padded, and with labels on the right */


    .rcheck label, .rcheck input,
    .rradio label, .rradio input
    {
        display: block;
        float: left;
    }

    .rcheck br, .rradio br {
        clear: both;
    }



/* for inline (e.g. yes/no) space out */
    .rinline input {
        margin-left: 2em;
    }


    .stdform textarea {
        width: 98%;
        overflow: scroll;
        /* IE strikes again */
        /* white-space: nowrap; */
    }




/* Special form elements -- warning messages, comments, etc. */

    /* Fancy error messages */


    /* Highlight error fields */
    .error input {
        background-color: #fee;
        border: 1px solid red;
    }

    /* To deal with margin collapse */
    div#ErrorsPad {
        height: 2em;
    }

    form div.error {
        background-color: #ffffe1;
        background-image: url(images/alert.gif);
        background-repeat: no-repeat;
        background-position: top left;
        color: #666666;
        border: 1px solid #ff0000;
        padding-bottom: 10px;
        margin-bottom: 5px;
    }
    form div.error p {
        font-size: 88%;
        font-weight: bold;
        margin: 0 0 0 22%;
        color: blue;
        margin-bottom: 5px;
    }

    div.error input {
        margin-bottom: 5px;
    }

    .stdform .comment {
        font-size: 0.9em;
        line-height: 0.9em;
        font-style: italic;
        color: blue;
        margin-left: 10%;
        margin-right: 20px;
        padding: 0px;
        margin-bottom: 3px;
    }
    .stdform .comment a {
        text-decoration: underline;
        color: blue;
    }
    .stdform .comment a:hover {
        color: #f59540;
        background-color: white;
    }




    /* Submit button */

    div.form-submit {
        text-align: center;
        margin: 2em 0;
        padding: 0;
    }



    .form-submit input.button {
        font-family: sans-serif;
        background-color: #44f;
        border: 1px solid black;
        padding: 4px;
        margin: 0;
        /* -moz-border-radius: 10px; */
    }

    .form-submit input.button:hover {
        color: #fff;
    }


